# Changelog

## [Version: 0.3.1] - 2025-07-12

### Added

- Initial implementation of the configuration parser.
- Initial logic for mirroring repositories.

### Changed

- No changes in this release.

### Fixed

- No bug fixes in this release.
